@@ -1,7 +1,7 @@
 package App::jsonsel;
 
-our $DATE = '2020-04-29'; # DATE
-our $VERSION = '0.007'; # VERSION
+our $DATE = '2021-02-19'; # DATE
+our $VERSION = '0.008'; # VERSION
 
 use 5.010001;
 use strict;
@@ -87,7 +87,7 @@ App::jsonsel - Select JSON elements using CSel (CSS-selector-like) syntax
 
 =head1 VERSION
 
-This document describes version 0.007 of App::jsonsel (from Perl distribution App-jsonsel), released on 2020-04-29.
+This document describes version 0.008 of App::jsonsel (from Perl distribution App-jsonsel), released on 2021-02-19.
 
 =head1 SYNOPSIS
 
@@ -204,7 +204,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-jsonsel>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-jsonsel>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-jsonsel/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -216,7 +216,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
